from jsonschema_spec.handlers import default_handlers
from jsonschema_spec.paths import Spec

__author__ = "Artur Maciag"
__email__ = "maciag.artur@gmail.com"
__version__ = "0.1.1"
__url__ = "https://github.com/p1c2u/jsonschema-spec"
__license__ = "Apache License, Version 2.0"

__all__ = ["Spec", "default_handlers"]
